Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1323)

Unified Diff: third_party/WebKit/public/platform/WebMediaPlayer.h

Issue 2791813003: Fix broken draw/upload paths from videos to 2D canvas and WebGL. (Closed)
Patch Set: Fix per review feedback from sandersd@. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/public/platform/WebMediaPlayer.h
diff --git a/third_party/WebKit/public/platform/WebMediaPlayer.h b/third_party/WebKit/public/platform/WebMediaPlayer.h
index 64b0939da7dae7f9ee3875445f7415a092f0aab0..ca6e294e4dbabf596d698c6d19581e502cc14a77 100644
--- a/third_party/WebKit/public/platform/WebMediaPlayer.h
+++ b/third_party/WebKit/public/platform/WebMediaPlayer.h
@@ -177,19 +177,19 @@ class WebMediaPlayer {
// TODO(kbr): remove non-|target| version. crbug.com/349871
//
// Do a GPU-GPU texture copy of the natural size of the current
// video frame to |texture|. Caller is responsible for allocating
// |texture| with the appropriate size. If the copy is impossible or
// fails, it returns false.
virtual bool copyVideoTextureToPlatformTexture(gpu::gles2::GLES2Interface*,
unsigned texture,
+ unsigned internalFormat,
+ unsigned type,
bool premultiplyAlpha,
bool flipY) {
return false;
}
- // TODO(kbr): when updating calling code to use this, remove the
- // |internalFormat| and |type| parameters. crbug.com/349871
// Do a GPU-GPU textures copy. If the copy is impossible or fails, it returns
// false.
virtual bool copyVideoTextureToPlatformTexture(gpu::gles2::GLES2Interface*,
@@ -177,19 +177,19 @@ class WebMediaPlayer {
// TODO(kbr): remove non-|target| version. crbug.com/349871
//
- // Do a GPU-GPU texture copy of the natural size of the current
- // video frame to |texture|. Caller is responsible for allocating
- // |texture| with the appropriate size. If the copy is impossible or
- // fails, it returns false.
+ // Do a GPU-GPU texture copy of the current video frame to |texture|,
+ // reallocating |texture| at the appropriate size with given internal
+ // format and type if necessary. If the copy is impossible or fails, it
+ // returns false.
virtual bool copyVideoTextureToPlatformTexture(gpu::gles2::GLES2Interface*,
unsigned texture,

Powered by Google App Engine
This is Rietveld 408576698